anterofit::executor

Module threaded

Executors using background threads

Structs

  • An executor which uses multiple threads to complete jobs.
  • An executor which uses a single thread to complete jobs.