anterofit
0.2.0
Module threaded
Module Items
Structs
In anterofit::
executor
anterofit
::
executor
Module
threaded
Executors using background threads
Structs

Multi
Thread
An executor which uses multiple threads to complete jobs.
Single
Thread
An executor which uses a single thread to complete jobs.